@@ -1,4 +1,4 @@
-from tex.vars import VAR_FRAGMENT, VAR_TOKEN_START, BLOCK_TOKEN_START, OPEN_BLOCK_FRAGMENT, TEXT_FRAGMENT, CLOSE_BLOCK_FRAGMENT
+from tex_engine.vars import VAR_FRAGMENT, VAR_TOKEN_START, BLOCK_TOKEN_START, OPEN_BLOCK_FRAGMENT, TEXT_FRAGMENT, CLOSE_BLOCK_FRAGMENT
 
 
 class Fragment(object):
