@@ -6,4 +6,4 @@ class Template(object):
         self.root = Compiler(contents).compile()
 
     def render(self, **kwargs):
-        return self.root.render(kwargs)
+        return bytes(self.root.render(kwargs), "utf-8")
